@@ -45,10 +45,6 @@
 # define FRIBIDI_PRIVATESPACE(SYMBOL) FRIBIDI_PRIVATESPACE0(_,FRIBIDI_NAMESPACE(_##SYMBOL##__internal__))
 #endif /* !FRIBIDI_PRIVATESPACE */
 
-#if (defined(WIN32)) || (defined(_WIN32_WCE))
-# define FRIBIDI_ENTRY __declspec(dllexport)
-#endif /* WIN32 */
-
 #if FRIBIDI_USE_GLIB+0
 # ifndef SIZEOF_LONG
 #  define SIZEOF_LONG GLIB_SIZEOF_LONG
